==> nextcloud-13.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ast.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Encontu pa la primer execución",
    "Add your profile information! For example your email is needed to reset your password." : "¡Amiesta la to información de perfil! Por exemplu, precísase'l to corréu pa reafitar la to contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita una semeya de perfil y un nome pa una reconocencia más fácil en toles carauterístiques.",
    "Add your profile information! Set a full name for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita un nome pa una reconocencia más fácil en toles carauterístiques.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita una semeya de perfil pa una reconocencia más fácil en toles carauterístiques.",
    "Get the apps to sync your files" : "Consigui les aplicaciones pa sincronizar los tos ficheros",
    "Desktop client" : "Veceru d'escritoriu",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "Connect your desktop apps to %s" : "Coneuta les tos aplicaciones d'escritoriu a %s",
    "Connect your calendar" : "Coneuta'l to calendariu",
    "Connect your contacts" : "Coneuta los tos contautos",
    "Access files via WebDAV" : "Accedi per WebDAV a los ficheros",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accedi o comparti los tos ficheros, calendarios, contautos, correos y más dende cualesquier preséu, so les tos regles propies",
    "Connect your Calendar" : "Coneuta'l to calendariu",
    "Connect your Contacts" : "Coneuta los tos contautos",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Hai más información na <a target=\"_blank\" href=\"%s\">documentación</a> y nel nuesu <a target=\"_blank\" href=\"%s\">sitiu web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si te presta Nextcloud, ¡<a href=\"mailto:?subject=Nextcloud &body=Nextcloud ye una aplicación llibre perbona pa sincronizar y compartir los tos ficheros. Pues consiguila de baldre dende https://nextcloud.com\"> aconséya-ylo a los tos collacios</a> y <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">collabora</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "¡Si quies sofitar el proyeutu {contributeopen}xúnite al desendolcu{linkclose} o {contributeopen}espardi'l mensaxe{linkclose}!",
    "Show First Run Wizard again" : "Volver amosar l'encontu pa la primer execución"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ast.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Encontu pa la primer execución",
    "Add your profile information! For example your email is needed to reset your password." : "¡Amiesta la to información de perfil! Por exemplu, precísase'l to corréu pa reafitar la to contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita una semeya de perfil y un nome pa una reconocencia más fácil en toles carauterístiques.",
    "Add your profile information! Set a full name for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita un nome pa una reconocencia más fácil en toles carauterístiques.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "¡Amiesta la to información de perfil! Afita una semeya de perfil pa una reconocencia más fácil en toles carauterístiques.",
    "Get the apps to sync your files" : "Consigui les aplicaciones pa sincronizar los tos ficheros",
    "Desktop client" : "Veceru d'escritoriu",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "Connect your desktop apps to %s" : "Coneuta les tos aplicaciones d'escritoriu a %s",
    "Connect your calendar" : "Coneuta'l to calendariu",
    "Connect your contacts" : "Coneuta los tos contautos",
    "Access files via WebDAV" : "Accedi per WebDAV a los ficheros",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "¡Si quies sofitar el proyeutu {contributeopen}xúnite al desendolcu{linkclose} o {contributeopen}espardi'l mensaxe{linkclose}!",
    "Show First Run Wizard again" : "Volver amosar l'encontu pa la primer execución",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accedi o comparti los tos ficheros, calendarios, contautos, correos y más dende cualesquier preséu, so les tos regles propies",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Hai más información na <a target=\"_blank\" href=\"%s\">documentación</a> y nel nuesu <a target=\"_blank\" href=\"%s\">sitiu web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si te presta Nextcloud, ¡<a href=\"mailto:?subject=Nextcloud &body=Nextcloud ye una aplicación llibre perbona pa sincronizar y compartir los tos ficheros. Pues consiguila de baldre dende https://nextcloud.com\"> aconséya-ylo a los tos collacios</a> y <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">collabora</a>!"
},
"nplurals=2; plural=(n != 1);");
